@@ -313,6 +313,8 @@ and minimal code that generates this warning. Thanks!
     # but these below are not necessary to run
     # if [Row|Column]#hidden? = false and [Row|Column]#outline_level == 0
     write_merged_cells
+    write_pagesetup
+    write_margins
     write_colinfos
     write_guts
 
@@ -498,6 +500,8 @@ and minimal code that generates this warning. Thanks!
     # ○  PHONETIC ➜ 5.77
     # ○  Conditional Formatting Table ➜ 4.12
     # ○  Hyperlink Table ➜ 4.13
+    write_pagesetup
+    write_margins
     write_hyperlink_table
     # ○  Data Validity Table ➜ 4.14
     # ○  SHEETLAYOUT ➜ 5.96 (BIFF8X only)
@@ -860,6 +864,27 @@ and minimal code that generates this warning. Thanks!
     end
   end
 
+  def write_pagesetup
+    return unless @worksheet.pagesetup
+    data = @worksheet.pagesetup[:orig_data].dup
+    if @worksheet.pagesetup[:orientation]
+      data[5] = @worksheet.pagesetup[:orientation] == :landscape ? 0 : 2
+    end
+
+    if @worksheet.pagesetup[:adjust_to]
+      data[1] = @worksheet.pagesetup[:adjust_to]
+    end
+
+    write_op opcode(:pagesetup), data.pack(binfmt(:pagesetup))
+  end
+
+  def write_margins
+    @worksheet.margins.each do |key, value|
+      next unless [:left, :top, :right, :bottom].include?(key)
+      write_op opcode(:"#{key}margin"), [value].pack(binfmt(:margin))
+    end
+  end
+
   def write_proctection
     return unless @worksheet.protected?
     # ○ PROTECT Worksheet contents: 1 = protected (➜ 5.82)
