@@ -128,6 +128,19 @@ module Spreadsheet
       @worksheet.row_updated @idx, self if @worksheet
       fmt
     end
+
+    def update_format(idx, opts = {})
+      if @formats[idx]
+        @formats[idx].update_format(opts)
+      else
+        fmt = default_format.clone
+        fmt.font = fmt.font.clone
+        @formats[idx] = fmt.update_format(opts)
+      end
+      @worksheet.add_format @formats[idx]
+      @worksheet.row_updated @idx, self if @worksheet
+    end
+
     private
     def index_of_first ary # :nodoc:
       if first = ary.find do |elm| !elm.nil? end
