@@ -1,8 +1,11 @@
 #!/usr/bin/env ruby
 # suite.rb -- spreadsheet -- 22.12.2011 -- jsaak@napalm.hu
-
+require 'rubygems'
+require 'bundler'
 require 'find'
 
+$VERBOSE = true
+
 here = File.dirname(__FILE__)
 
 $: << here
